* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization)
  * Step 2: Scope Applications
